# common-General.md
## bye
* goodbye "Talk to you later!"
    
Bye
Goodbye
See you later
Bye bot
Goodbye friend
bye
bye for now
catch you later
gotta go
See you
goodnight
have a nice day
i'm off
see you later alligator
we'll speak soon

## greet
* ask name "Hey there! Tell me your name."
@ story joke
    - name{"name":"Lucy"}
    + greet
    - joke ..
    - thank ..
    - bye ..

Hi
Hey
Hi bot
Hey bot
Hello
Good morning
hi again
hi folks
hi Mister
hi pal!
hi there
greetings
hello everybody
hello is anybody there
hello robot

## thank
* thanks "My pleasure."

Thanks
Thank you
Thank you so much
Thanks bot
Thanks for that
cheers
cheers bro
ok thanks!
perfect thank you
thanks a bunch for everything
thanks for the help
thanks a lot
amazing, thanks
cool, thanks
cool thank you

## affirm
yes
yes sure
absolutely
for sure
yes yes yes
definitely

## name
* greet "Nice to you meet you {name}. How can I help?"

My name is [name:o](Juste) 
I am [name:o](Josh)
I'm [name:o](Lucy)
People call me [name:o](Greg)
It's [name:o](David)
Usually people call me [name:o](Amy)
My name is [name:o](John)
You can call me [name:o](Sam)
Please call me [name:o](Linda)
Name name is [name:o](Tom)
I am [name:o](Richard)
I'm [name:o](Tracy)
Call me [name:o](Sally)
I am [name:o](Philipp)
I am [name:o](Charlie)

## joke
* action joke

Can you tell me a joke?
I would like to hear a joke
Tell me a joke
A joke please
Tell me a joke please
I would like to hear a joke
I would loke to hear a joke, please
Can you tell jokes?
Please tell me a joke
I need to hear a joke
